/**
 * DiCloud - GENI project
 * 
 * (C) 2010 - University of Massachusetts Amherst
 * 
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package edu.umass.cs.geni.ec2.accounting;

import java.sql.Timestamp;

/**
 * This class defines an AWS activity to be logged for accounting. An activity
 * is issued by a service (EC2, S3, EBS, ...) and has a description of the
 * operation along with its cost and timestamp. <br>
 * The cost is usually negative except when new credit is added to the AWS
 * account in which case the cost is positive.
 * 
 * @author <a href="mailto:cecchet@cs.umass.edu">Emmanuel Cecchet </a>
 * @version 1.0
 * 
 */
public class AWSActivity
{
  private String service;
  private String operation;
  private double cost;
  private long   time;

  /**
   * Create a new AWS activity
   * 
   * @param service
   *          Service performing the operation (EC2, S3, EBS, ...)
   * @param operation
   *          Description of the operation
   * @param cost
   *          Cost of the operation (negative if debit, positive if credit)
   * @param time
   *          Time when the operation occurred (milliseconds since January 1,
   *          1970, 00:00:00 GMT. A negative number is the number of
   *          milliseconds before January 1, 1970, 00:00:00 GMT.)
   */
  public AWSActivity(String service, String operation, double cost, long time)
  {
	this.service = service;
	this.operation = operation;
	this.cost = cost;
	this.time = time;
  }

  /**
   * @return the service
   */
  public String getService()
  {
	return service;
  }

  /**
   * @param service
   *          the service to set
   */
  public void setService(String service)
  {
	this.service = service;
  }

  /**
   * @return the operation
   */
  public String getOperation()
  {
	return operation;
  }

  /**
   * @param operation
   *          the operation to set
   */
  public void setOperation(String operation)
  {
	this.operation = operation;
  }

  /**
   * @return the cost
   */
  public double getCost()
  {
	return cost;
  }

  /**
   * @param cost
   *          the cost to set
   */
  public void setCost(double cost)
  {
	this.cost = cost;
  }

  /**
   * @return the time
   */
  public long getTime()
  {
	return time;
  }

  /**
   * @param time
   *          the time to set
   */
  public void setTime(long time)
  {
	this.time = time;
  }

  /*
   * (non-Javadoc)
   * 
   * @see java.lang.Object#toString()
   */
  @Override
  public String toString()
  {
	return (new Timestamp(time)).toString() + "/Service: " + service
	    + "/Operation: " + operation + "/Cost: " + cost;
  }

}
