/**
 * DiCloud - GENI project
 * 
 * (C) 2010 - University of Massachusetts Amherst
 * 
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package edu.umass.cs.geni.ec2.accounting;

/**
 * This class defines an EC2 instance by its type, region and instance id. The
 * type and region are used to retrieve the cost of the instance as defined in
 * ec2pricing.properties.
 * 
 * @author <a href="mailto:cecchet@cs.umass.edu">Emmanuel Cecchet </a>
 * @version 1.0
 * 
 */
public class EC2Instance
{
  private String instanceType;
  private String region;
  private String instanceId;
  private long   lastBilledTime;

  /**
   * Create a new EC2Instance object using the current time as the last billed
   * time.
   * 
   * @param instanceType
   *          EC2 instance type
   * @param region
   *          EC2 region
   * @param instanceId
   *          Instance identifier
   */
  public EC2Instance(String instanceType, String region, String instanceId)
  {
	this.instanceType = instanceType;
	this.region = region;
	this.instanceId = instanceId;
	this.lastBilledTime = System.currentTimeMillis();
  }

  /**
   * @return the instanceType
   */
  public String getInstanceType()
  {
	return instanceType;
  }

  /**
   * @param instanceType
   *          the instanceType to set
   */
  public void setInstanceType(String instanceType)
  {
	this.instanceType = instanceType;
  }

  /**
   * @return the region
   */
  public String getRegion()
  {
	return region;
  }

  /**
   * @param region
   *          the region to set
   */
  public void setRegion(String region)
  {
	this.region = region;
  }

  /**
   * @return the instanceId
   */
  public String getInstanceId()
  {
	return instanceId;
  }

  /**
   * @param instanceId
   *          the instanceId to set
   */
  public void setInstanceId(String instanceId)
  {
	this.instanceId = instanceId;
  }

  /**
   * @return the lastBilledTime
   */
  public long getLastBilledTime()
  {
	return lastBilledTime;
  }

  /**
   * @param lastBilledTime
   *          the lastBilledTime to set
   */
  public void setLastBilledTime(long lastBilledTime)
  {
	this.lastBilledTime = lastBilledTime;
  }

}
