/**
 * DiCloud - GENI project
 * 
 * (C) 2010 - University of Massachusetts Amherst
 * 
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package edu.umass.cs.geni.ec2.handlers;

import java.util.Properties;

import org.apache.log4j.Logger;

import edu.umass.cs.geni.ec2.AmazonProperties;

import orca.shirako.plugins.ShirakoPlugin;
import orca.shirako.plugins.config.Config;

/**
 * Tests the EBS Handler
 * 
 * @author <a href="mailto:cecchet@cs.umass.edu">Emmanuel Cecchet </a>
 * @version 1.0
 * 
 */
public class TestEBSHandler
{

  /**
   * @param args
   */
  public static void main(String[] args)
  {
	Properties p = new Properties();
	p.put(AmazonProperties.AWS_CERT_FILE,
	    "/home/manu/ec2/keys/cert-PKPHQWFUX6DU7GRIRPMWXVGN6SYYNI3B.pem");
	p.put(AmazonProperties.AWS_PRIVATE_KEY_FILE,
	    "/home/manu/ec2/keys/pk-PKPHQWFUX6DU7GRIRPMWXVGN6SYYNI3B.pem");
	p.put(AmazonProperties.EC2_REGION, "us-east-1");
	p.put(AmazonProperties.EC2_AVAILABILITY_ZONE, "us-east-1a");
	p.put(AmazonProperties.EBS_SIZE_IN_GB, "1");

	try
	{
	  AWSPlugin plugin = new AWSPlugin();
	  plugin.setLogger(Logger.getRootLogger());
	  plugin.initialize();
	  EBSHandler handler = new EBSHandler(plugin);
	  handler.initialize();

	  // Create instance
	  ebs_join(p, plugin, handler);

	  // Probe instance
	  p.put(AmazonProperties.EBS_VOLUME_ID, plugin.getConfigurationProperties()
		  .get(AmazonProperties.EBS_VOLUME_ID));
	  for (int i = 0; i < 6; i++)
	  {
		ebs_probe(p, plugin, handler);
		Thread.sleep(10000);
	  }

	  // Delete instance
	  ebs_leave(p, plugin, handler);
	}
	catch (Exception e)
	{
	  // TODO Auto-generated catch block
	  e.printStackTrace();
	}
  }

  private static void ebs_join(Properties p, ShirakoPlugin plugin,
	  EBSHandler handler) throws Exception
  {
	handler.join(null, p);

	Properties props = plugin.getConfigurationProperties();
	String result = props.getProperty(Config.PropertyTargetResultCode);
	System.out.println("Join result code: " + result);
	System.out.println("command status: "
	    + props.getProperty(Config.PropertyTargetResultCodeMessage));
	System.out.println("Error code:"
	    + props.getProperty(Config.PropertyExceptionMessage));
	System.out.println("Error stack:"
	    + props.getProperty(Config.PropertyExceptionStack));

	if (!"0".equals(result))
	  throw new Exception("Failed to create EBS volume");

	System.out.println("Volume ID: "
	    + props.getProperty(AmazonProperties.EBS_VOLUME_ID));
	System.out.println("Volume status: "
	    + props.getProperty(AmazonProperties.EBS_STATUS));
	System.out.println("Creation time: "
	    + props.getProperty(AmazonProperties.EBS_CREATION_TIME));
  }

  private static void ebs_probe(Properties p, ShirakoPlugin plugin,
	  EBSHandler handler) throws Exception
  {
	handler.probe(null, p);

	Properties props = plugin.getConfigurationProperties();
	String result = props.getProperty(Config.PropertyTargetResultCode);
	System.out.println("Probing result code: " + result);

	if ("0".equals(result))
	{
	  System.out.println("Volume ID: "
		  + props.getProperty(AmazonProperties.EBS_VOLUME_ID));
	  System.out.println("Volume status: "
		  + props.getProperty(AmazonProperties.EBS_STATUS));
	  System.out.println("Creation time: "
		  + props.getProperty(AmazonProperties.EBS_CREATION_TIME));
	  System.out.println("Region: "
		  + props.getProperty(AmazonProperties.EC2_REGION));
	}
	else
	{
	  System.out.println("Error code:"
		  + props.getProperty(Config.PropertyExceptionMessage));
	  System.out.println("Error stack:"
		  + props.getProperty(Config.PropertyExceptionStack));
	  throw new Exception("Failed to probe EBS volume");
	}
  }

  private static void ebs_leave(Properties p, ShirakoPlugin plugin,
	  EBSHandler handler) throws Exception
  {
	handler.leave(null, p);

	Properties props = plugin.getConfigurationProperties();
	String result = props.getProperty(Config.PropertyTargetResultCode);
	System.out.println("Leave result code: " + result);
	System.out.println("Status: "
	    + props.getProperty(Config.PropertyTargetResultCodeMessage));
	System.out.println("Error code:"
	    + props.getProperty(Config.PropertyExceptionMessage));
	System.out.println("Error stack:"
	    + props.getProperty(Config.PropertyExceptionStack));

	if (!"0".equals(result))
	  throw new Exception("Failed to delete EBS volume");
  }

}
